@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,19 +35,22 @@
  */
 package net.sourceforge.plantuml;
 
-import net.sourceforge.plantuml.cucadiagram.DisplayPositionned;
+import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
 import net.sourceforge.plantuml.cucadiagram.DisplaySection;
 
 public interface Annotated {
 
-	public DisplayPositionned getTitle();
+	public DisplayPositioned getTitle();
 
-	public DisplayPositionned getCaption();
+	public DisplayPositioned getCaption();
 
-	public DisplayPositionned getLegend();
+	public DisplayPositioned getLegend();
 
 	public DisplaySection getHeader();
 
 	public DisplaySection getFooter();
 
+	public Display getMainFrame();
+
 }
