@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,65 +35,72 @@
  */
 package net.sourceforge.plantuml;
 
+import java.util.Collection;
+
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.DotSplines;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
 import net.sourceforge.plantuml.graphic.SkinParameter;
 import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.skin.ActorStyle;
 import net.sourceforge.plantuml.skin.ArrowDirection;
+import net.sourceforge.plantuml.skin.Padder;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleBuilder;
+import net.sourceforge.plantuml.svek.ConditionEndStyle;
 import net.sourceforge.plantuml.svek.ConditionStyle;
 import net.sourceforge.plantuml.svek.PackageStyle;
-import net.sourceforge.plantuml.ugraphic.ColorMapper;
+import net.sourceforge.plantuml.svg.LengthAdjust;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UStroke;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
 
 public interface ISkinParam extends ISkinSimple {
 
 	public static final int SWIMLANE_WIDTH_SAME = -1;
 
-	public HtmlColor getHyperlinkColor();
+	public HColor getHyperlinkColor();
 
 	public boolean useUnderlineForHyperlink();
 
-	public HtmlColor getBackgroundColor();
+	public HColor getBackgroundColor();
 
-	public HtmlColor getHtmlColor(ColorParam param, Stereotype stereotype, boolean clickable);
+	public HColor getHtmlColor(ColorParam param, Stereotype stereotype, boolean clickable);
 
-	public Colors getColors(ColorParam param, Stereotype stereotype);
+	public Colors getColors(ColorParam param, Stereotype stereotype) throws NoSuchColorException;
 
-	public HtmlColor getFontHtmlColor(Stereotype stereotype, FontParam... param);
+	public HColor getFontHtmlColor(Stereotype stereotype, FontParam... param);
 
 	public UStroke getThickness(LineParam param, Stereotype stereotype);
 
 	public UFont getFont(Stereotype stereotype, boolean inPackageTitle, FontParam... fontParam);
 
-	public HorizontalAlignment getHorizontalAlignment(AlignmentParam param, ArrowDirection arrowDirection);
+	public HorizontalAlignment getHorizontalAlignment(AlignmentParam param, ArrowDirection arrowDirection,
+			boolean isReverseDefine, HorizontalAlignment overrideDefault);
 
 	public HorizontalAlignment getDefaultTextAlignment(HorizontalAlignment defaultValue);
 
+	public HorizontalAlignment getStereotypeAlignment();
+
 	public int getCircledCharacterRadius();
 
 	public char getCircledCharacter(Stereotype stereotype);
 
 	public int classAttributeIconSize();
 
-	public ColorMapper getColorMapper();
-
 	public DotSplines getDotSplines();
 
-	public String getDotExecutable();
-
-	public boolean shadowing();
+	public boolean shadowing(Stereotype stereotype);
 
 	public boolean shadowingForNote(Stereotype stereotype);
 
-	public boolean shadowing2(SkinParameter skinParameter);
+	public boolean shadowing2(Stereotype stereotype, SkinParameter skinParameter);
 
-	public PackageStyle getPackageStyle();
+	public PackageStyle packageStyle();
 
-	public boolean useUml2ForComponent();
+	public ComponentStyle componentStyle();
 
 	public boolean stereotypePositionTop();
 
@@ -119,7 +126,7 @@ public interface ISkinParam extends ISkinSimple {
 
 	public ConditionStyle getConditionStyle();
 
-	public double minClassWidth();
+	public ConditionEndStyle getConditionEndStyle();
 
 	public boolean sameClassWidth();
 
@@ -129,12 +136,14 @@ public interface ISkinParam extends ISkinSimple {
 
 	public int groupInheritance();
 
-	public boolean useGuillemet();
+	public Guillemet guillemet();
 
 	public boolean handwritten();
 
 	public String getSvgLinkTarget();
 
+	public String getPreserveAspectRatio();
+
 	public int getTabSize();
 
 	public int maxAsciiMessageLength();
@@ -147,7 +156,7 @@ public interface ISkinParam extends ISkinSimple {
 
 	public UmlDiagramType getUmlDiagramType();
 
-	public HtmlColor getHoverPathColor();
+	public HColor hoverPathColor();
 
 	public TikzFontDistortion getTikzFontDistortion();
 
@@ -161,4 +170,30 @@ public interface ISkinParam extends ISkinSimple {
 
 	public boolean svgDimensionStyle();
 
-}
\ No newline at end of file
+	public boolean fixCircleLabelOverlapping();
+
+	public void setUseVizJs(boolean useVizJs);
+
+	public boolean isUseVizJs();
+
+	public Padder sequenceDiagramPadder();
+
+	public StyleBuilder getCurrentStyleBuilder();
+
+	public void muteStyle(Style modifiedStyle);
+
+	public Collection<String> getAllSpriteNames();
+
+	public String getDefaultSkin();
+
+	public void setDefaultSkin(String newSkin);
+
+	public ActorStyle actorStyle();
+
+	public void setSvgSize(String origin, String sizeToUse);
+
+	public LengthAdjust getlengthAdjust();
+
+	public void assumeTransparent(ThemeStyle style);
+
+}
