@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,15 +35,14 @@
  */
 package net.sourceforge.plantuml;
 
-import java.io.File;
 import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
 import java.io.PrintStream;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.cucadiagram.dot.GraphvizUtils;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
+import net.sourceforge.plantuml.security.SFile;
+import net.sourceforge.plantuml.security.SecurityUtils;
 
 public class OptionFlags {
 
@@ -55,8 +54,11 @@ public class OptionFlags {
 
 	static public boolean ALLOW_INCLUDE = true;
 
+	static public void setAllowIncludeFalse() {
+		ALLOW_INCLUDE = false;
+	}
+
 	static public void setMaxPixel(int max) {
-		ImageBuilder.setMaxPixel(max);
 	}
 
 	static public final boolean USE_HECTOR = false;
@@ -69,7 +71,7 @@ public class OptionFlags {
 	static public final boolean USE_INTERFACE_EYE2 = false;
 	// static public final boolean SWI2 = false;
 	// static public final boolean USE_COMPOUND = false;
-	static public final boolean OMEGA_CROSSING = false;
+	// static public final boolean OMEGA_CROSSING = false;
 
 	// static public final boolean LINK_BETWEEN_FIELDS = true;
 
@@ -87,7 +89,6 @@ public class OptionFlags {
 	}
 
 	private void reset(boolean exit) {
-		// keepTmpFiles = false;
 		verbose = false;
 		extractFromMetadata = false;
 		word = false;
@@ -96,7 +97,6 @@ public class OptionFlags {
 		quiet = false;
 		checkDotError = false;
 		printFonts = false;
-		// useSuggestEngine = true;
 		// failOnError = false;
 		encodesprite = false;
 		// PIC_LINE = false;
@@ -106,7 +106,6 @@ public class OptionFlags {
 		return false;
 	}
 
-	// private boolean keepTmpFiles;
 	private boolean verbose;
 	private boolean extractFromMetadata;
 	private boolean word;
@@ -115,7 +114,6 @@ public class OptionFlags {
 	private boolean quiet;
 	private boolean checkDotError;
 	private boolean printFonts;
-	// private boolean useSuggestEngine;
 	private boolean encodesprite;
 	private boolean dumpHtmlStats;
 	private boolean dumpStats;
@@ -123,12 +121,14 @@ public class OptionFlags {
 	private boolean overwrite;
 	private boolean enableStats = defaultForStats();
 	private boolean stdLib;
+	private boolean silentlyCompletelyIgnoreErrors;
+	private boolean replaceWhiteBackgroundByTransparent;
 	private boolean extractStdLib;
 	private boolean clipboardLoop;
 	private boolean clipboard;
 	private String fileSeparator = "_";
 	private long timeoutMs = 15 * 60 * 1000L; // 15 minutes
-	private File logData;
+	private SFile logData;
 
 	public static OptionFlags getInstance() {
 		return singleton;
@@ -192,7 +192,7 @@ public class OptionFlags {
 
 	private final AtomicBoolean logDataInitized = new AtomicBoolean(false);
 
-	public void logData(File file, Diagram system) {
+	public void logData(final SFile file, Diagram system) {
 		final String warnOrError = system.getWarningOrError();
 		if (warnOrError == null) {
 			return;
@@ -201,7 +201,7 @@ public class OptionFlags {
 			if (logData == null && logDataInitized.get() == false) {
 				final String s = GraphvizUtils.getenvLogData();
 				if (s != null) {
-					setLogData(new File(s));
+					setLogData(new SFile(s));
 				}
 				logDataInitized.set(true);
 			}
@@ -210,9 +210,7 @@ public class OptionFlags {
 				return;
 			}
 			// final PSystemError systemError = (PSystemError) system;
-			PrintStream ps = null;
-			try {
-				ps = new PrintStream(new FileOutputStream(logData, true));
+			try (PrintStream ps = SecurityUtils.createPrintStream(logData.createFileOutputStream(true))) {
 				ps.println("Start of " + file.getName());
 				ps.println(warnOrError);
 				ps.println("End of " + file.getName());
@@ -220,28 +218,18 @@ public class OptionFlags {
 			} catch (FileNotFoundException e) {
 				Log.error("Cannot open " + logData);
 				e.printStackTrace();
-			} finally {
-				if (ps != null) {
-					ps.close();
-				}
 			}
 		}
 	}
 
-	public final void setLogData(File logData) {
+	public final void setLogData(SFile logData) {
 		this.logData = logData;
 		logData.delete();
-		PrintStream ps = null;
-		try {
-			ps = new PrintStream(new FileOutputStream(logData));
+		try (PrintStream ps = SecurityUtils.createPrintStream(logData.createFileOutputStream())) {
 			ps.println();
 		} catch (FileNotFoundException e) {
 			Log.error("Cannot open " + logData);
 			e.printStackTrace();
-		} finally {
-			if (ps != null) {
-				ps.close();
-			}
 		}
 	}
 
@@ -257,14 +245,6 @@ public class OptionFlags {
 		return false;
 	}
 
-	// public final boolean isUseSuggestEngine() {
-	// return useSuggestEngine;
-	// }
-	//
-	// public final void setUseSuggestEngine(boolean useSuggestEngine) {
-	// this.useSuggestEngine = useSuggestEngine;
-	// }
-
 	public final boolean isEncodesprite() {
 		return encodesprite;
 	}
@@ -368,4 +348,20 @@ public class OptionFlags {
 	public final void setStdLib(boolean stdLib) {
 		this.stdLib = stdLib;
 	}
+
+	public final boolean isSilentlyCompletelyIgnoreErrors() {
+		return silentlyCompletelyIgnoreErrors;
+	}
+
+	public final void setSilentlyCompletelyIgnoreErrors(boolean silentlyCompletelyIgnoreErrors) {
+		this.silentlyCompletelyIgnoreErrors = silentlyCompletelyIgnoreErrors;
+	}
+
+	public final boolean isReplaceWhiteBackgroundByTransparent() {
+		return replaceWhiteBackgroundByTransparent;
+	}
+
+	public final void setReplaceWhiteBackgroundByTransparent(boolean replaceWhiteBackgroundByTransparent) {
+		this.replaceWhiteBackgroundByTransparent = replaceWhiteBackgroundByTransparent;
+	}
 }
