@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,19 +35,20 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.command;
 
-import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.activitydiagram3.ActivityDiagram3;
 import net.sourceforge.plantuml.activitydiagram3.ftile.BoxStyle;
 import net.sourceforge.plantuml.command.BlocLines;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.command.CommandMultilines2;
 import net.sourceforge.plantuml.command.MultilinesStrategy;
+import net.sourceforge.plantuml.command.regex.IRegex;
 import net.sourceforge.plantuml.command.regex.RegexConcat;
 import net.sourceforge.plantuml.command.regex.RegexLeaf;
 import net.sourceforge.plantuml.command.regex.RegexResult;
 import net.sourceforge.plantuml.graphic.color.ColorParser;
 import net.sourceforge.plantuml.graphic.color.ColorType;
 import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
 
 public class CommandActivityLong3 extends CommandMultilines2<ActivityDiagram3> {
 
@@ -57,29 +58,32 @@ public class CommandActivityLong3 extends CommandMultilines2<ActivityDiagram3> {
 
 	@Override
 	public String getPatternEnd() {
-		return "^(.*)" + CommandActivity3.ENDING_GROUP + "$";
+		return "^(.*)" + CommandActivity3.endingGroup() + "$";
 	}
 
 	private static ColorParser color() {
 		return ColorParser.simpleColor(ColorType.BACK);
 	}
 
-	static RegexConcat getRegexConcat() {
-		return new RegexConcat(new RegexLeaf("^"), //
+	static IRegex getRegexConcat() {
+		return RegexConcat.build(CommandActivityLong3.class.getName(), RegexLeaf.start(), //
 				color().getRegex(), //
 				new RegexLeaf(":"), //
 				new RegexLeaf("DATA", "(.*)"), //
-				new RegexLeaf("$"));
+				RegexLeaf.end());
 	}
 
-	public CommandExecutionResult executeNow(ActivityDiagram3 diagram, BlocLines lines) {
+	@Override
+	protected CommandExecutionResult executeNow(ActivityDiagram3 diagram, BlocLines lines) throws NoSuchColorException {
 		lines = lines.removeEmptyColumns();
-		final RegexResult line0 = getStartingPattern().matcher(StringUtils.trin(lines.getFirst499()));
-		final Colors colors = color().getColor(line0, diagram.getSkinParam().getIHtmlColorSet());
-		// final HtmlColor color = diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(line0.get("COLOR", 0));
+		final RegexResult line0 = getStartingPattern().matcher(lines.getFirst().getTrimmed().getString());
+		final Colors colors = color().getColor(diagram.getSkinParam().getThemeStyle(), line0,
+				diagram.getSkinParam().getIHtmlColorSet());
+		// final HtmlColor color =
+		// diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(line0.get("COLOR",
+		// 0));
 		final BoxStyle style = BoxStyle.fromChar(lines.getLastChar());
-		lines = lines.removeStartingAndEnding2(line0.get("DATA", 0));
-		diagram.addActivity(lines.toDisplay(), style, null, colors);
-		return CommandExecutionResult.ok();
+		lines = lines.removeStartingAndEnding(line0.get("DATA", 0), 1);
+		return diagram.addActivity(lines.toDisplay(), style, null, colors, null);
 	}
 }
