@@ -61,6 +61,7 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.FtileFactoryDele
 import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.FtileFactoryDelegatorWhile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.UGraphicInterceptorOneSwimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.VCompactFactory;
+import net.sourceforge.plantuml.activitydiagram3.gtile.GConnection;
 import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
@@ -195,6 +196,15 @@ public class Swimlanes extends AbstractTextBlock implements TextBlock, Styleable
 					final ConnectionCross connectionCross = new ConnectionCross(connection);
 					connectionCross.drawU(getUg());
 				}
+			} else if (shape instanceof Gtile) {
+				final Gtile tile = (Gtile) shape;
+				tile.drawU(this);
+			} else if (shape instanceof GConnection) {
+				final GConnection connection = (GConnection) shape;
+				System.err.println("CROSS IN SWIMLANES");
+				connection.drawTranslatable(getUg());
+				// connection.drawU(this);
+				// throw new UnsupportedOperationException();
 			}
 		}
 
@@ -236,9 +246,13 @@ public class Swimlanes extends AbstractTextBlock implements TextBlock, Styleable
 		TextBlock full = root.createGtile(skinParam, ug.getStringBounder());
 
 		ug = new UGraphicForSnake(ug);
-		full = new TextBlockInterceptorUDrawable(full);
-		full.drawU(ug);
-		ug.flushUg();
+		if (swimlanes().size() > 1) {
+			drawWhenSwimlanes(ug, full);
+		} else {
+			full = new TextBlockInterceptorUDrawable(full);
+			full.drawU(ug);
+			ug.flushUg();
+		}
 
 	}
 
