@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,6 +35,7 @@
  */
 package net.sourceforge.plantuml.classdiagram.command;
 
+import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
@@ -44,11 +45,13 @@ import net.sourceforge.plantuml.command.regex.MyPattern;
 import net.sourceforge.plantuml.command.regex.Pattern2;
 import net.sourceforge.plantuml.command.regex.RegexConcat;
 import net.sourceforge.plantuml.command.regex.RegexLeaf;
+import net.sourceforge.plantuml.command.regex.RegexOptional;
 import net.sourceforge.plantuml.command.regex.RegexOr;
 import net.sourceforge.plantuml.command.regex.RegexResult;
 import net.sourceforge.plantuml.cucadiagram.Code;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.IEntity;
+import net.sourceforge.plantuml.cucadiagram.Ident;
 import net.sourceforge.plantuml.cucadiagram.LeafType;
 import net.sourceforge.plantuml.cucadiagram.Link;
 import net.sourceforge.plantuml.cucadiagram.LinkDecor;
@@ -63,22 +66,31 @@ final public class CommandLinkLollipop extends SingleLineCommand2<AbstractClassO
 	}
 
 	static RegexConcat getRegexConcat(UmlDiagramType umlDiagramType) {
-		return new RegexConcat(new RegexLeaf("HEADER", "^(?:@([\\d.]+)[%s]+)?"), //
+		return RegexConcat.build(CommandLinkLollipop.class.getName() + umlDiagramType, RegexLeaf.start(), //
+				new RegexOptional( //
+						new RegexConcat( //
+								new RegexLeaf("HEADER", "@([\\d.]+)"), //
+								RegexLeaf.spaceOneOrMore() //
+						)), //
 				new RegexLeaf("ENT1", "(?:" + optionalKeywords(umlDiagramType) + "[%s]+)?"
-						+ "(\\.?[\\p{L}0-9_]+(?:\\.[\\p{L}0-9_]+)*|[%g][^%g]+[%g])[%s]*(\\<\\<.*\\>\\>)?"), //
-				new RegexLeaf("[%s]*"), //
-				new RegexLeaf("FIRST_LABEL", "(?:[%g]([^%g]+)[%g])?"), //
-				new RegexLeaf("[%s]*"), //
-				new RegexOr(new RegexLeaf("LOL_THEN_ENT", "\\(\\)([-=.]+)"), //
-						new RegexLeaf("ENT_THEN_LOL", "([-=.]+)\\(\\)")), //
-				new RegexLeaf("[%s]*"), //
-				new RegexLeaf("SECOND_LABEL", "(?:[%g]([^%g]+)[%g])?"), //
-				new RegexLeaf("[%s]*"), //
+						+ "(\\.?[%pLN_]+(?:\\.[%pLN_]+)*|[%g][^%g]+[%g])[%s]*(\\<\\<.*\\>\\>)?"), //
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexOptional(new RegexLeaf("FIRST_LABEL", "[%g]([^%g]+)[%g]")), //
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexOr(new RegexLeaf("LOL_THEN_ENT", "([()]\\))([-=.]+)"), //
+						new RegexLeaf("ENT_THEN_LOL", "([-=.]+)(\\([()])")), //
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexOptional(new RegexLeaf("SECOND_LABEL", "[%g]([^%g]+)[%g]")), //
+				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf("ENT2", "(?:" + optionalKeywords(umlDiagramType) + "[%s]+)?"
-						+ "(\\.?[\\p{L}0-9_]+(?:\\.[\\p{L}0-9_]+)*|[%g][^%g]+[%g])[%s]*(\\<\\<.*\\>\\>)?"), //
-				new RegexLeaf("[%s]*"), //
-				new RegexLeaf("LABEL_LINK", "(?::[%s]*(.+))?"), //
-				new RegexLeaf("$"));
+						+ "(\\.?[%pLN_]+(?:\\.[%pLN_]+)*|[%g][^%g]+[%g])[%s]*(\\<\\<.*\\>\\>)?"), //
+				RegexLeaf.spaceZeroOrMore(), //
+				new RegexOptional( //
+						new RegexConcat( //
+								new RegexLeaf(":"), //
+								RegexLeaf.spaceZeroOrMore(), //
+								new RegexLeaf("LABEL_LINK", "(.+)") //
+						)), RegexLeaf.end());
 	}
 
 	private static String optionalKeywords(UmlDiagramType type) {
@@ -91,27 +103,41 @@ final public class CommandLinkLollipop extends SingleLineCommand2<AbstractClassO
 		throw new IllegalArgumentException();
 	}
 
-	@Override
-	protected CommandExecutionResult executeArg(AbstractClassOrObjectDiagram diagram, RegexResult arg) {
+	private LeafType getType(String desc) {
+		if (desc.charAt(0) == desc.charAt(1)) {
+			return LeafType.LOLLIPOP_HALF;
+		}
+		return LeafType.LOLLIPOP_FULL;
+	}
 
-		final Code ent1 = Code.of(arg.get("ENT1", 1));
-		final Code ent2 = Code.of(arg.get("ENT2", 1));
+	@Override
+	protected CommandExecutionResult executeArg(AbstractClassOrObjectDiagram diagram, LineLocation location,
+			RegexResult arg) {
+
+		final String ent1 = arg.get("ENT1", 1);
+		final String ent2 = arg.get("ENT2", 1);
 
 		final IEntity cl1;
 		final IEntity cl2;
 		final IEntity normalEntity;
 
 		final String suffix = "lol" + UniqueSequence.getValue();
-		if (arg.get("LOL_THEN_ENT", 0) == null) {
+		if (arg.get("LOL_THEN_ENT", 1) == null) {
 			assert arg.get("ENT_THEN_LOL", 0) != null;
-			cl1 = diagram.getOrCreateLeaf(ent1, null, null);
-			cl2 = diagram.createLeaf(cl1.getCode().addSuffix(suffix), Display.getWithNewlines(ent2), LeafType.LOLLIPOP,
-					null);
+			final Ident ident1 = diagram.buildLeafIdent(ent1);
+			final Code ent1code = diagram.V1972() ? ident1 : diagram.buildCode(ent1);
+			cl1 = getFoo1(diagram, ent1code, ident1);
+			final Ident idNewLong = diagram.buildLeafIdent(ent1 + suffix);
+			cl2 = diagram.createLeaf(idNewLong, idNewLong.toCode(diagram), Display.getWithNewlines(ent2),
+					getType(arg.get("ENT_THEN_LOL", 1)), null);
 			normalEntity = cl1;
 		} else {
-			cl2 = diagram.getOrCreateLeaf(ent2, null, null);
-			cl1 = diagram.createLeaf(cl2.getCode().addSuffix(suffix), Display.getWithNewlines(ent1), LeafType.LOLLIPOP,
-					null);
+			final Ident ident2 = diagram.buildLeafIdent(ent2);
+			final Code ent2code = diagram.V1972() ? ident2 : diagram.buildCode(ent2);
+			cl2 = getFoo1(diagram, ent2code, ident2);
+			final Ident idNewLong = diagram.buildLeafIdent(ent2 + suffix);
+			cl1 = diagram.createLeaf(idNewLong, idNewLong.toCode(diagram), Display.getWithNewlines(ent1),
+					getType(arg.get("LOL_THEN_ENT", 0)), null);
 			normalEntity = cl2;
 		}
 
@@ -167,13 +193,24 @@ final public class CommandLinkLollipop extends SingleLineCommand2<AbstractClassO
 		 */
 
 		final Link link = new Link(cl1, cl2, linkType, Display.getWithNewlines(labelLink), length, firstLabel,
-				secondLabel, diagram.getLabeldistance(), diagram.getLabelangle());
+				secondLabel, diagram.getLabeldistance(), diagram.getLabelangle(), diagram.getSkinParam()
+						.getCurrentStyleBuilder());
 		diagram.resetPragmaLabel();
 		addLink(diagram, link, arg.get("HEADER", 0));
 
 		return CommandExecutionResult.ok();
 	}
 
+	private IEntity getFoo1(AbstractClassOrObjectDiagram diagram, final Code code, final Ident ident) {
+		if (diagram.V1972()) {
+			final IEntity result = ident.size() == 1 ? diagram.getLeafVerySmart(ident) : diagram.getLeafStrict(ident);
+			if (result != null) {
+				return result;
+			}
+		}
+		return diagram.getOrCreateLeaf(ident, code, null, null);
+	}
+
 	// private String merge(String a, String b) {
 	// if (a == null && b == null) {
 	// return null;
@@ -216,8 +253,8 @@ final public class CommandLinkLollipop extends SingleLineCommand2<AbstractClassO
 	}
 
 	private String getQueue(RegexResult arg) {
-		if (arg.get("LOL_THEN_ENT", 0) != null) {
-			return StringUtils.trin(arg.get("LOL_THEN_ENT", 0));
+		if (arg.get("LOL_THEN_ENT", 1) != null) {
+			return StringUtils.trin(arg.get("LOL_THEN_ENT", 1));
 		}
 		if (arg.get("ENT_THEN_LOL", 0) != null) {
 			return StringUtils.trin(arg.get("ENT_THEN_LOL", 0));
