@@ -56,7 +56,7 @@ import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.cucadiagram.Bodier;
 import net.sourceforge.plantuml.cucadiagram.Code;
 import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositionned;
+import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
 import net.sourceforge.plantuml.cucadiagram.EntityPosition;
 import net.sourceforge.plantuml.cucadiagram.EntityUtils;
 import net.sourceforge.plantuml.cucadiagram.GroupRoot;
@@ -95,7 +95,7 @@ final public class EntityImpl implements ILeaf, IGroup {
 	private final Bodier bodier;
 	private final String uid = StringUtils.getUid("cl", UniqueSequence.getValue());
 	private Display display = Display.empty();
-	private DisplayPositionned legend = null;
+	private DisplayPositioned legend = null;
 
 	private LeafType leafType;
 	private Stereotype stereotype;
@@ -749,12 +749,12 @@ final public class EntityImpl implements ILeaf, IGroup {
 		return visibility;
 	}
 
-	public void setLegend(DisplayPositionned legend) {
+	public void setLegend(DisplayPositioned legend) {
 		checkGroup();
 		this.legend = legend;
 	}
 
-	public DisplayPositionned getLegend() {
+	public DisplayPositioned getLegend() {
 		return legend;
 	}
 
