@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -36,26 +36,28 @@
 package net.sourceforge.plantuml.skin.rose;
 
 import java.awt.geom.Dimension2D;
+import java.util.Objects;
 
 import net.sourceforge.plantuml.ISkinSimple;
 import net.sourceforge.plantuml.LineBreakStrategy;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
-import net.sourceforge.plantuml.graphic.HtmlColorTransparent;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.SymbolContext;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.skin.AbstractTextualComponent;
 import net.sourceforge.plantuml.skin.Area;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
-import net.sourceforge.plantuml.ugraphic.UChangeColor;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UPolygon;
+import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.URectangle;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.HColorBackground;
 
 public class ComponentRoseGroupingHeader extends AbstractTextualComponent {
 
@@ -64,16 +66,32 @@ public class ComponentRoseGroupingHeader extends AbstractTextualComponent {
 
 	private final TextBlock commentTextBlock;
 
-	private final HtmlColor background;
+	private final HColor background;
 	private final SymbolContext symbolContext;
+	private final SymbolContext symbolContextCorner;
+	private final double roundCorner;
 
-	public ComponentRoseGroupingHeader(HtmlColor background, SymbolContext symbolContext, FontConfiguration bigFont,
-			FontConfiguration smallFont2, Display strings, ISkinSimple spriteContainer) {
-		super(LineBreakStrategy.NONE, strings.get(0), bigFont, HorizontalAlignment.LEFT, 15, 30, 1, spriteContainer,
-				null, null);
+	public ComponentRoseGroupingHeader(Style style, Style styleHeader, HColor background, SymbolContext symbolContext,
+			FontConfiguration bigFont, FontConfiguration smallFont2, Display strings, ISkinSimple spriteContainer,
+			double roundCorner) {
+		super(styleHeader, LineBreakStrategy.NONE, strings.get(0), bigFont, HorizontalAlignment.LEFT, 15, 30, 1,
+				spriteContainer, null, null);
 
-		this.symbolContext = symbolContext;
-		this.background = background;
+		if (UseStyle.useBetaStyle()) {
+			this.roundCorner = style.value(PName.RoundCorner).asInt();
+			this.background = style.value(PName.BackGroundColor).asColor(spriteContainer.getThemeStyle(),
+					getIHtmlColorSet());
+			this.symbolContext = style.getSymbolContext(spriteContainer.getThemeStyle(), getIHtmlColorSet());
+			this.symbolContextCorner = styleHeader.getSymbolContext(spriteContainer.getThemeStyle(),
+					getIHtmlColorSet());
+			bigFont = style.getFontConfiguration(spriteContainer.getThemeStyle(), getIHtmlColorSet());
+			smallFont2 = style.getFontConfiguration(spriteContainer.getThemeStyle(), getIHtmlColorSet());
+		} else {
+			this.roundCorner = roundCorner;
+			this.background = background;
+			this.symbolContext = symbolContext;
+			this.symbolContextCorner = symbolContext;
+		}
 		if (strings.size() == 1 || strings.get(1) == null) {
 			this.commentTextBlock = null;
 		} else {
@@ -81,12 +99,11 @@ public class ComponentRoseGroupingHeader extends AbstractTextualComponent {
 			// final FontConfiguration smallFont2 = bigFont.forceFont(smallFont, null);
 			this.commentTextBlock = display.create(smallFont2, HorizontalAlignment.LEFT, spriteContainer);
 		}
-		if (this.background == null) {
-			throw new IllegalArgumentException();
-		}
+		Objects.requireNonNull(this.background);
 	}
 
-	// new FontConfiguration(smallFont, bigFont.getColor(), bigFont.getHyperlinkColor(),
+	// new FontConfiguration(smallFont, bigFont.getColor(),
+	// bigFont.getHyperlinkColor(),
 	// bigFont.useUnderlineForHyperlink());
 
 	private double getSuppHeightForComment(StringBounder stringBounder) {
@@ -121,38 +138,34 @@ public class ComponentRoseGroupingHeader extends AbstractTextualComponent {
 
 	@Override
 	protected void drawBackgroundInternalU(UGraphic ug, Area area) {
-		if (background instanceof HtmlColorTransparent) {
+		if (background instanceof HColorBackground) {
 			return;
 		}
 		final Dimension2D dimensionToUse = area.getDimensionToUse();
-		ug = symbolContext.applyStroke(ug).apply(new UChangeColor(symbolContext.getForeColor()));
-		final URectangle rect = new URectangle(dimensionToUse.getWidth(), dimensionToUse.getHeight());
+		ug = symbolContext.applyStroke(ug).apply(symbolContext.getForeColor());
+		final URectangle rect = new URectangle(dimensionToUse.getWidth(), dimensionToUse.getHeight())
+				.rounded(roundCorner);
 		rect.setDeltaShadow(symbolContext.getDeltaShadow());
-		ug.apply(new UChangeBackColor(background)).draw(rect);
+		ug.apply(background.bg()).draw(rect);
 	}
 
 	@Override
 	protected void drawInternalU(UGraphic ug, Area area) {
 		final Dimension2D dimensionToUse = area.getDimensionToUse();
-		ug = symbolContext.applyStroke(ug).apply(new UChangeColor(symbolContext.getForeColor()));
-		final URectangle rect = new URectangle(dimensionToUse.getWidth(), dimensionToUse.getHeight());
-		ug.draw(rect);
-
 		final StringBounder stringBounder = ug.getStringBounder();
 		final int textWidth = (int) getTextWidth(stringBounder);
 		final int textHeight = (int) getTextHeight(stringBounder);
 
-		final UPolygon polygon = new UPolygon();
-		polygon.addPoint(0, 0);
-		polygon.addPoint(textWidth, 0);
+		if (UseStyle.useBetaStyle()) {
+			symbolContextCorner.apply(ug).draw(getCorner(textWidth, textHeight));
+		} else {
+			symbolContextCorner.applyColors(ug).draw(getCorner(textWidth, textHeight));
+		}
 
-		polygon.addPoint(textWidth, textHeight - cornersize);
-		polygon.addPoint(textWidth - cornersize, textHeight);
-
-		polygon.addPoint(0, textHeight);
-		polygon.addPoint(0, 0);
-
-		symbolContext.applyColors(ug).draw(polygon);
+		ug = symbolContext.applyStroke(ug).apply(symbolContext.getForeColor());
+		final URectangle rect = new URectangle(dimensionToUse.getWidth(), dimensionToUse.getHeight())
+				.rounded(roundCorner);
+		ug.draw(rect);
 
 		ug = ug.apply(new UStroke());
 
@@ -166,4 +179,31 @@ public class ComponentRoseGroupingHeader extends AbstractTextualComponent {
 		}
 	}
 
+	private UPath getCorner(final double width, final double height) {
+		final UPath polygon = new UPath();
+		if (roundCorner == 0) {
+			polygon.moveTo(0, 0);
+			polygon.lineTo(width, 0);
+
+			polygon.lineTo(width, height - cornersize);
+			polygon.lineTo(width - cornersize, height);
+
+			polygon.lineTo(0, height);
+			polygon.lineTo(0, 0);
+		} else {
+			polygon.moveTo(roundCorner / 2, 0);
+			polygon.lineTo(width, 0);
+
+			polygon.lineTo(width, height - cornersize);
+			polygon.lineTo(width - cornersize, height);
+
+			polygon.lineTo(0, height);
+			polygon.lineTo(0, roundCorner / 2);
+
+			polygon.arcTo(roundCorner / 2, roundCorner / 2, 0, 0, 1, roundCorner / 2, 0);
+
+		}
+		return polygon;
+	}
+
 }
