@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -36,43 +36,51 @@
 package net.sourceforge.plantuml.svg;
 
 import java.awt.geom.Dimension2D;
+import java.awt.geom.PathIterator;
 import java.awt.image.BufferedImage;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
+import java.util.Objects;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
-import javax.imageio.ImageIO;
 import javax.xml.parsers.DocumentBuilder;
-import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerException;
-import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
-import net.sourceforge.plantuml.Log;
-import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.SvgString;
-import net.sourceforge.plantuml.code.Base64Coder;
-import net.sourceforge.plantuml.eps.EpsGraphics;
-import net.sourceforge.plantuml.graphic.HtmlColorGradient;
-import net.sourceforge.plantuml.ugraphic.ColorMapper;
-import net.sourceforge.plantuml.ugraphic.UPath;
-import net.sourceforge.plantuml.ugraphic.USegment;
-import net.sourceforge.plantuml.ugraphic.USegmentType;
-
 import org.w3c.dom.CDATASection;
 import org.w3c.dom.Comment;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
+import net.sourceforge.plantuml.FileUtils;
+import net.sourceforge.plantuml.Log;
+import net.sourceforge.plantuml.SignatureUtils;
+import net.sourceforge.plantuml.code.Base64Coder;
+import net.sourceforge.plantuml.security.SImageIO;
+import net.sourceforge.plantuml.security.SecurityUtils;
+import net.sourceforge.plantuml.tikz.TikzGraphics;
+import net.sourceforge.plantuml.ugraphic.UGroupType;
+import net.sourceforge.plantuml.ugraphic.UImageSvg;
+import net.sourceforge.plantuml.ugraphic.UPath;
+import net.sourceforge.plantuml.ugraphic.USegment;
+import net.sourceforge.plantuml.ugraphic.USegmentType;
+import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
+import net.sourceforge.plantuml.ugraphic.color.HColorGradient;
+import net.sourceforge.plantuml.xml.XmlFactories;
+
 public class SvgGraphics {
 
 	// http://tutorials.jenkov.com/svg/index.html
@@ -88,6 +96,11 @@ public class SvgGraphics {
 	// http://www.w3schools.com/svg/svg_feoffset.asp
 	// http://www.adobe.com/svg/demos/samples.html
 
+	private static final String XLINK_TITLE1 = "title";
+	private static final String XLINK_TITLE2 = "xlink:title";
+	private static final String XLINK_HREF1 = "href";
+	private static final String XLINK_HREF2 = "xlink:href";
+
 	final private Document document;
 	final private Element root;
 	final private Element defs;
@@ -102,11 +115,16 @@ public class SvgGraphics {
 	private int maxX = 10;
 	private int maxY = 10;
 
+	private final String preserveAspectRatio;
+
 	private final double scale;
 	private final String filterUid;
 	private final String shadowId;
 	private final String gradientId;
 	private final boolean svgDimensionStyle;
+	private final LengthAdjust lengthAdjust;
+
+	private final boolean INTERACTIVE = false;
 
 	final protected void ensureVisible(double x, double y) {
 		if (x > maxX) {
@@ -117,17 +135,15 @@ public class SvgGraphics {
 		}
 	}
 
-	public SvgGraphics(boolean svgDimensionStyle, Dimension2D minDim, double scale, String hover, long seed) {
-		this(svgDimensionStyle, minDim, null, scale, hover, seed);
-	}
-
-	public SvgGraphics(boolean svgDimensionStyle, Dimension2D minDim, String backcolor, double scale, String hover,
-			long seed) {
+	public SvgGraphics(String backcolor, boolean svgDimensionStyle, Dimension2D minDim, double scale, String hover,
+			long seed, String preserveAspectRatio, LengthAdjust lengthAdjust) {
 		try {
+			this.lengthAdjust = lengthAdjust;
 			this.svgDimensionStyle = svgDimensionStyle;
 			this.scale = scale;
 			this.document = getDocument();
 			this.backcolor = backcolor;
+			this.preserveAspectRatio = preserveAspectRatio;
 			ensureVisible(minDim.getWidth(), minDim.getHeight());
 
 			this.root = getRootNode();
@@ -143,12 +159,55 @@ public class SvgGraphics {
 			if (hover != null) {
 				defs.appendChild(getPathHover(hover));
 			}
+
+			if (INTERACTIVE) {
+				final Element styles = getStylesForInteractiveMode();
+				if (styles != null) {
+					defs.appendChild(styles);
+				}
+				final Element script = getScriptForInteractiveMode();
+				if (script != null) {
+					defs.appendChild(script);
+				}
+			}
 		} catch (ParserConfigurationException e) {
 			e.printStackTrace();
 			throw new IllegalStateException(e);
 		}
 	}
 
+	private Element getStylesForInteractiveMode() {
+		final Element style = simpleElement("style");
+		final String text = getData("default.css");
+		if (text == null) {
+			return null;
+		}
+		final CDATASection cdata = document.createCDATASection(text);
+		style.setAttribute("type", "text/css");
+		style.appendChild(cdata);
+		return style;
+	}
+
+	private Element getScriptForInteractiveMode() {
+		final Element script = document.createElement("script");
+		final String text = getData("default.js");
+		if (text == null) {
+			return null;
+		}
+		script.setTextContent(text);
+		return script;
+	}
+
+	private static String getData(final String name) {
+		try {
+			final InputStream is = SvgGraphics.class.getResourceAsStream("/svg/" + name);
+			return FileUtils.readText(is);
+		} catch (IOException e) {
+			e.printStackTrace();
+			return null;
+		}
+	}
+
 	private Element getPathHover(String hover) {
 		final Element style = simpleElement("style");
 		final CDATASection cdata = document.createCDATASection("path:hover { stroke: " + hover + " !important;}");
@@ -163,9 +222,8 @@ public class SvgGraphics {
 
 	private Element pendingBackground;
 
-	public void paintBackcolorGradient(ColorMapper mapper, HtmlColorGradient gr) {
-		final String id = createSvgGradient(StringUtils.getAsHtml(mapper.getMappedColor(gr.getColor1())),
-				StringUtils.getAsHtml(mapper.getMappedColor(gr.getColor2())), gr.getPolicy());
+	public void paintBackcolorGradient(ColorMapper mapper, HColorGradient gr) {
+		final String id = createSvgGradient(mapper.toRGB(gr.getColor1()), mapper.toRGB(gr.getColor2()), gr.getPolicy());
 		setFillColor("url(#" + id + ")");
 		setStrokeColor(null);
 		pendingBackground = createRectangleInternal(0, 0, 0, 0);
@@ -181,9 +239,7 @@ public class SvgGraphics {
 	}
 
 	private Document getDocument() throws ParserConfigurationException {
-		final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
-
-		final DocumentBuilder builder = factory.newDocumentBuilder();
+		final DocumentBuilder builder = XmlFactories.newDocumentBuilder();
 		final Document document = builder.newDocument();
 		document.setXmlStandalone(true);
 		return document;
@@ -217,7 +273,7 @@ public class SvgGraphics {
 			elt.setAttribute("cy", format(y));
 			elt.setAttribute("rx", format(xRadius));
 			elt.setAttribute("ry", format(yRadius));
-			elt.setAttribute("fill", fill);
+			fillMe(elt);
 			elt.setAttribute("style", getStyle());
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
@@ -231,7 +287,7 @@ public class SvgGraphics {
 					+ format(x2) + " " + format(y2);
 			final Element elt = (Element) document.createElement("path");
 			elt.setAttribute("d", path);
-			elt.setAttribute("fill", fill);
+			fillMe(elt);
 			elt.setAttribute("style", getStyle());
 			getG().appendChild(elt);
 		}
@@ -298,41 +354,7 @@ public class SvgGraphics {
 		this.strokeDasharray = strokeDasharray;
 	}
 
-	public void closeLink() {
-		if (pendingAction.size() > 0) {
-			final Element element = pendingAction.get(0);
-			pendingAction.remove(0);
-			if (element.getFirstChild() != null) {
-				// Empty link
-				getG().appendChild(element);
-			}
-		}
-	}
-
-	private final List<Element> pendingAction = new ArrayList<Element>();
-
-	public void openLink(String url, String title, String target) {
-		if (url == null) {
-			throw new IllegalArgumentException();
-		}
-
-		if (pendingAction.size() > 0) {
-			closeLink();
-		}
-
-		pendingAction.add(0, (Element) document.createElement("a"));
-		pendingAction.get(0).setAttribute("target", target);
-		pendingAction.get(0).setAttribute("xlink:href", url);
-		pendingAction.get(0).setAttribute("xlink:type", "simple");
-		pendingAction.get(0).setAttribute("xlink:actuate", "onRequest");
-		pendingAction.get(0).setAttribute("xlink:show", "new");
-		if (title == null) {
-			pendingAction.get(0).setAttribute("xlink:title", url);
-		} else {
-			title = title.replaceAll("\\\\n", "\n");
-			pendingAction.get(0).setAttribute("xlink:title", title);
-		}
-	}
+	private final List<Element> pendingAction = new ArrayList<>();
 
 	public final Element getG() {
 		if (pendingAction.size() == 0) {
@@ -342,7 +364,7 @@ public class SvgGraphics {
 	}
 
 	public void svgRectangle(double x, double y, double width, double height, double rx, double ry, double deltaShadow,
-			String id) {
+			String id, String codeLine) {
 		if (height <= 0 || width <= 0) {
 			return;
 			// To be restored when Teoz will be finished
@@ -359,6 +381,9 @@ public class SvgGraphics {
 			if (id != null) {
 				elt.setAttribute("id", id);
 			}
+			if (codeLine != null) {
+				elt.setAttribute("codeLine", codeLine);
+			}
 			getG().appendChild(elt);
 		}
 		ensureVisible(x + width + 2 * deltaShadow, y + height + 2 * deltaShadow);
@@ -370,8 +395,8 @@ public class SvgGraphics {
 		elt.setAttribute("y", format(y));
 		elt.setAttribute("width", format(width));
 		elt.setAttribute("height", format(height));
-		elt.setAttribute("fill", fill);
-		elt.setAttribute("style", getStyle());
+		fillMe(elt);
+		elt.setAttribute("style", getStyleSpecial());
 		return elt;
 	}
 
@@ -392,18 +417,34 @@ public class SvgGraphics {
 	}
 
 	private String getStyle() {
-		return getStyleInternal(stroke, strokeWidth, strokeDasharray);
+		final StringBuilder style = new StringBuilder();
+		style.append("stroke:" + stroke + ";");
+		style.append("stroke-width:" + strokeWidth + ";");
+		if (fill.equals("#00000000")) {
+			style.append("fill:none;");
+		}
+		if (strokeDasharray != null) {
+			style.append("stroke-dasharray:" + strokeDasharray + ";");
+		}
+		return style.toString();
 	}
 
-	private static String getStyleInternal(String color, String strokeWidth, String strokeDasharray) {
-		final StringBuilder style = new StringBuilder("stroke: " + color + "; stroke-width: " + strokeWidth + ";");
+	// https://forum.plantuml.net/12469/package-background-transparent-package-default-background?show=12479#c12479
+	private String getStyleSpecial() {
+		final StringBuilder style = new StringBuilder();
+		style.append("stroke:" + stroke + ";");
+		style.append("stroke-width:" + strokeWidth + ";");
+		if (fill.equals("#00000000")) {
+			style.append("fill:none;");
+		}
 		if (strokeDasharray != null) {
-			style.append(" stroke-dasharray: " + strokeDasharray + ";");
+			style.append("stroke-dasharray:" + strokeDasharray + ";");
 		}
 		return style.toString();
 	}
 
 	public void svgPolygon(double deltaShadow, double... points) {
+		assert points.length % 2 == 0;
 		manageShadow(deltaShadow);
 		if (hidden == false) {
 			final Element elt = (Element) document.createElement("polygon");
@@ -415,8 +456,8 @@ public class SvgGraphics {
 				sb.append(format(coord));
 			}
 			elt.setAttribute("points", sb.toString());
-			elt.setAttribute("fill", fill);
-			elt.setAttribute("style", getStyle());
+			fillMe(elt);
+			elt.setAttribute("style", getStyleSpecial());
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
 		}
@@ -436,11 +477,18 @@ public class SvgGraphics {
 			// elt.setAttribute("text-rendering", "geometricPrecision");
 			elt.setAttribute("x", format(x));
 			elt.setAttribute("y", format(y));
-			elt.setAttribute("fill", fill);
+			fillMe(elt);
 			elt.setAttribute("font-size", format(fontSize));
 			// elt.setAttribute("text-anchor", "middle");
-			elt.setAttribute("lengthAdjust", "spacingAndGlyphs");
-			elt.setAttribute("textLength", format(textLength));
+
+			if (lengthAdjust == LengthAdjust.SPACING) {
+				elt.setAttribute("lengthAdjust", "spacing");
+				elt.setAttribute("textLength", format(textLength));
+			} else if (lengthAdjust == LengthAdjust.SPACING_AND_GLYPHS) {
+				elt.setAttribute("lengthAdjust", "spacingAndGlyphs");
+				elt.setAttribute("textLength", format(textLength));
+			}
+
 			if (fontWeight != null) {
 				elt.setAttribute("font-weight", fontWeight);
 			}
@@ -471,16 +519,17 @@ public class SvgGraphics {
 			elt.setTextContent(text);
 			getG().appendChild(elt);
 
-			if (textDecoration != null && textDecoration.contains("underline")) {
-				final double delta = 2;
-				final Element elt2 = (Element) document.createElement("line");
-				elt2.setAttribute("x1", format(x));
-				elt2.setAttribute("y1", format(y + delta));
-				elt2.setAttribute("x2", format(x + textLength));
-				elt2.setAttribute("y2", format(y + delta));
-				elt2.setAttribute("style", getStyleInternal(fill, "1.0", null));
-				getG().appendChild(elt2);
-			}
+			// http://forum.plantuml.net/9158/hyperlink-without-underline
+			// if (textDecoration != null && textDecoration.contains("underline")) {
+			// final double delta = 2;
+			// final Element elt2 = (Element) document.createElement("line");
+			// elt2.setAttribute("x1", format(x));
+			// elt2.setAttribute("y1", format(y + delta));
+			// elt2.setAttribute("x2", format(x + textLength));
+			// elt2.setAttribute("y2", format(y + delta));
+			// elt2.setAttribute("style", getStyleInternal(fill, "1.0", null));
+			// getG().appendChild(elt2);
+			// }
 
 		}
 		ensureVisible(x, y);
@@ -517,19 +566,7 @@ public class SvgGraphics {
 	}
 
 	private Transformer getTransformer() throws TransformerException {
-		// Get a TransformerFactory object.
-		TransformerFactory xformFactory = null;
-		try {
-			final Class<?> factoryClass = Class
-					.forName("com.sun.org.apache.xalan.internal.xsltc.trax.TransformerFactoryImpl");
-			xformFactory = (TransformerFactory) factoryClass.newInstance();
-		} catch (Exception e) {
-			xformFactory = TransformerFactory.newInstance();
-		}
-		Log.info("TransformerFactory=" + xformFactory.getClass());
-
-		// Get an XSL Transformer object.
-		final Transformer transformer = xformFactory.newTransformer();
+		final Transformer transformer = XmlFactories.newTransformer();
 		Log.info("Transformer=" + transformer.getClass());
 
 		// // Sets the standalone property in the first line of
@@ -550,12 +587,18 @@ public class SvgGraphics {
 		createXmlInternal(baos);
 		String s = new String(baos.toByteArray());
 		for (Map.Entry<String, String> ent : images.entrySet()) {
-			final String k = "\\<" + ent.getKey() + "/\\>";
-			s = s.replaceAll(k, ent.getValue());
+			final String k = "<" + ent.getKey() + "/>";
+			s = s.replace(k, ent.getValue());
 		}
+		s = removeXmlHeader(s);
 		os.write(s.getBytes());
 	}
 
+	private String removeXmlHeader(String s) {
+		s = s.replaceFirst("^<\\?xml [^<>]+?\\>", "");
+		return s;
+	}
+
 	private void createXmlInternal(OutputStream os) throws TransformerException {
 		// // Add lines
 		// for (Line l : lines) {
@@ -579,7 +622,7 @@ public class SvgGraphics {
 		}
 		root.setAttribute("viewBox", "0 0 " + maxXscaled + " " + maxYscaled);
 		root.setAttribute("zoomAndPan", "magnify");
-		root.setAttribute("preserveAspectRatio", "none");
+		root.setAttribute("preserveAspectRatio", preserveAspectRatio);
 		root.setAttribute("contentScriptType", "application/ecmascript");
 		root.setAttribute("contentStyleType", "text/css");
 
@@ -629,7 +672,7 @@ public class SvgGraphics {
 			} else if (type == USegmentType.SEG_CLOSE) {
 				// Nothing
 			} else {
-				Log.println("unknown " + seg);
+				Log.println("unknown3 " + seg);
 			}
 
 		}
@@ -637,16 +680,33 @@ public class SvgGraphics {
 			final Element elt = (Element) document.createElement("path");
 			elt.setAttribute("d", sb.toString());
 			elt.setAttribute("style", getStyle());
-			elt.setAttribute("fill", fill);
+			fillMe(elt);
 			final String id = path.getComment();
 			if (id != null) {
 				elt.setAttribute("id", id);
 			}
+			final String codeLine = path.getCodeLine();
+			if (codeLine != null) {
+				elt.setAttribute("codeLine", codeLine);
+			}
 			addFilterShadowId(elt, deltaShadow);
 			getG().appendChild(elt);
 		}
 	}
 
+	private void fillMe(Element elt) {
+		if (fill.equals("#00000000")) {
+			return;
+		}
+		if (fill.matches("#[0-9A-Fa-f]{8}")) {
+			elt.setAttribute("fill", fill.substring(0, 7));
+			final double opacity = Integer.parseInt(fill.substring(7), 16) / 255.0;
+			elt.setAttribute("fill-opacity", String.format(Locale.US, "%1.5f", opacity));
+		} else {
+			elt.setAttribute("fill", fill);
+		}
+	}
+
 	private void addFilterShadowId(final Element elt, double deltaShadow) {
 		if (deltaShadow > 0) {
 			elt.setAttribute("filter", "url(#" + shadowId + ")");
@@ -691,7 +751,7 @@ public class SvgGraphics {
 	}
 
 	private String format(double x) {
-		return EpsGraphics.format(x * scale);
+		return TikzGraphics.format(x * scale);
 	}
 
 	private String formatBoolean(double x) {
@@ -702,6 +762,7 @@ public class SvgGraphics {
 		if (hidden == false) {
 			final Element elt = (Element) document.createElement("path");
 			elt.setAttribute("d", currentPath.toString());
+			fillMe(elt);
 			// elt elt.setAttribute("style", getStyle());
 			getG().appendChild(elt);
 		}
@@ -709,6 +770,33 @@ public class SvgGraphics {
 
 	}
 
+	public void drawPathIterator(double x, double y, PathIterator path) {
+
+		this.newpath();
+		final double coord[] = new double[6];
+		while (path.isDone() == false) {
+			final int code = path.currentSegment(coord);
+			if (code == PathIterator.SEG_MOVETO) {
+				this.moveto(coord[0] + x, coord[1] + y);
+			} else if (code == PathIterator.SEG_LINETO) {
+				this.lineto(coord[0] + x, coord[1] + y);
+			} else if (code == PathIterator.SEG_CLOSE) {
+				this.closepath();
+			} else if (code == PathIterator.SEG_CUBICTO) {
+				this.curveto(coord[0] + x, coord[1] + y, coord[2] + x, coord[3] + y, coord[4] + x, coord[5] + y);
+			} else if (code == PathIterator.SEG_QUADTO) {
+				this.quadto(coord[0] + x, coord[1] + y, coord[2] + x, coord[3] + y);
+			} else {
+				throw new UnsupportedOperationException("code=" + code);
+			}
+
+			path.next();
+		}
+
+		this.fill(path.getWindingRule());
+
+	}
+
 	public void svgImage(BufferedImage image, double x, double y) throws IOException {
 		if (hidden == false) {
 			final Element elt = (Element) document.createElement("image");
@@ -726,12 +814,12 @@ public class SvgGraphics {
 
 	private final Map<String, String> images = new HashMap<String, String>();
 
-	public void svgImage(SvgString image, double x, double y) {
+	public void svgImage(UImageSvg image, double x, double y) {
 		if (hidden == false) {
 			String svg = manageScale(image);
 			final String pos = "<svg x=\"" + format(x) + "\" y=\"" + format(y) + "\">";
 			svg = pos + svg.substring(5);
-			final String key = "imagesvginlined" + images.size();
+			final String key = "imagesvginlined" + image.getMD5Hex() + images.size();
 			final Element elt = (Element) document.createElement(key);
 			getG().appendChild(elt);
 			images.put(key, svg);
@@ -740,19 +828,27 @@ public class SvgGraphics {
 		ensureVisible(x + image.getData("width"), y + image.getData("height"));
 	}
 
-	private String manageScale(SvgString svg) {
-		final double svgScale = svg.getScale();
+	private String manageScale(UImageSvg svgImage) {
+		final double svgScale = svgImage.getScale();
+		String svg = svgImage.getSvg(false);
 		if (svgScale * scale == 1) {
-			return svg.getSvg(false);
+			return svg;
 		}
+		final String svg2 = svg.replace('\n', ' ').replace('\r', ' ');
+		if (svg2.contains("<g ") == false && svg2.contains("<g>") == false) {
+			svg = svg.replaceFirst("\\<svg\\>", "<svg><g>");
+			svg = svg.replaceFirst("\\</svg\\>", "</g></svg>");
+		}
+		final String factor = format(svgScale);
 		final String s1 = "\\<g\\b";
-		final String s2 = "<g transform=\"scale(" + format(svgScale) + "," + format(svgScale) + ")\" ";
-		return svg.getSvg(false).replaceFirst(s1, s2);
+		final String s2 = "<g transform=\"scale(" + factor + "," + factor + ")\" ";
+		svg = svg.replaceFirst(s1, s2);
+		return svg;
 	}
 
 	private String toBase64(BufferedImage image) throws IOException {
 		final ByteArrayOutputStream baos = new ByteArrayOutputStream();
-		ImageIO.write(image, "png", baos);
+		SImageIO.write(image, "png", baos);
 		final byte data[] = baos.toByteArray();
 		return new String(Base64Coder.encode(data));
 	}
@@ -774,8 +870,8 @@ public class SvgGraphics {
 				addFilter(filter, "feGaussianBlur", "result", "blurOut", "stdDeviation", "" + (2 * scale));
 				addFilter(filter, "feColorMatrix", "type", "matrix", "in", "blurOut", "result", "blurOut2", "values",
 						"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 .4 0");
-				addFilter(filter, "feOffset", "result", "blurOut3", "in", "blurOut2", "dx", "" + (4 * scale), "dy", ""
-						+ (4 * scale));
+				addFilter(filter, "feOffset", "result", "blurOut3", "in", "blurOut2", "dx", "" + (4 * scale), "dy",
+						"" + (4 * scale));
 				addFilter(filter, "feBlend", "in", "SourceGraphic", "in2", "blurOut3", "mode", "normal");
 				defs.appendChild(filter);
 
@@ -785,6 +881,7 @@ public class SvgGraphics {
 	}
 
 	private void addFilter(Element filter, String name, String... data) {
+		assert data.length % 2 == 0;
 		final Element elt = (Element) document.createElement(name);
 		for (int i = 0; i < data.length; i += 2) {
 			elt.setAttribute(data[i], data[i + 1]);
@@ -798,9 +895,86 @@ public class SvgGraphics {
 		this.hidden = hidden;
 	}
 
+	public static final String MD5_HEADER = "<!--MD5=[";
+
+	public static String getMD5Hex(String comment) {
+		return SignatureUtils.getMD5Hex(comment);
+	}
+
 	public void addComment(String comment) {
+		final String signature = getMD5Hex(comment);
+		comment = "MD5=[" + signature + "]\n" + comment;
 		final Comment commentElement = document.createComment(comment);
 		getG().appendChild(commentElement);
 	}
 
+	public void openLink(String url, String title, String target) {
+		Objects.requireNonNull(url);
+
+		// javascript: security issue
+		if (SecurityUtils.getJavascriptUnsecure() == false && url.toLowerCase().startsWith("javascript")) {
+			return;
+		}
+
+		if (pendingAction.size() > 0) {
+			closeLink();
+		}
+
+		pendingAction.add(0, (Element) document.createElement("a"));
+		pendingAction.get(0).setAttribute("target", target);
+		pendingAction.get(0).setAttribute(XLINK_HREF1, url);
+		pendingAction.get(0).setAttribute(XLINK_HREF2, url);
+		pendingAction.get(0).setAttribute("xlink:type", "simple");
+		pendingAction.get(0).setAttribute("xlink:actuate", "onRequest");
+		pendingAction.get(0).setAttribute("xlink:show", "new");
+		if (title == null) {
+			pendingAction.get(0).setAttribute(XLINK_TITLE1, url);
+			pendingAction.get(0).setAttribute(XLINK_TITLE2, url);
+		} else {
+			title = formatTitle(title);
+			pendingAction.get(0).setAttribute(XLINK_TITLE1, title);
+			pendingAction.get(0).setAttribute(XLINK_TITLE2, title);
+		}
+	}
+
+	private String formatTitle(String title) {
+		final Pattern p = Pattern.compile("\\<U\\+([0-9A-Fa-f]+)\\>");
+		final Matcher m = p.matcher(title);
+		final StringBuffer sb = new StringBuffer();
+		while (m.find()) {
+			final String num = m.group(1);
+			final char c = (char) Integer.parseInt(num, 16);
+			m.appendReplacement(sb, "" + c);
+		}
+		m.appendTail(sb);
+
+		title = sb.toString().replaceAll("\\\\n", "\n");
+		return title;
+	}
+
+	public void closeLink() {
+		if (pendingAction.size() > 0) {
+			final Element element = pendingAction.get(0);
+			pendingAction.remove(0);
+			if (element.getFirstChild() != null) {
+				// Empty link
+				getG().appendChild(element);
+			}
+		}
+	}
+
+	public void startGroup(UGroupType type, String ident) {
+		if (type == UGroupType.ID) {
+			pendingAction.add(0, (Element) document.createElement("g"));
+			pendingAction.get(0).setAttribute("id", ident);
+		} else if (INTERACTIVE && type == UGroupType.CLASS) {
+			pendingAction.add(0, (Element) document.createElement("g"));
+			pendingAction.get(0).setAttribute("class", ident);
+		}
+	}
+
+	public void closeGroup() {
+		closeLink();
+	}
+
 }
