@@ -71,7 +71,7 @@ import javax.swing.WindowConstants;
 import net.sourceforge.plantuml.GeneratedImage;
 import net.sourceforge.plantuml.ImageSelection;
 import net.sourceforge.plantuml.graphic.GraphicStrings;
-import net.sourceforge.plantuml.security.ImageIO;
+import net.sourceforge.plantuml.security.SImageIO;
 import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 import net.sourceforge.plantuml.version.PSystemVersion;
@@ -314,7 +314,7 @@ class ImageWindow extends JFrame {
 		final File png = generatedImage.getPngFile();
 		BufferedImage image = null;
 		try {
-			image = ImageIO.read(new SFile(png.getAbsolutePath()));
+			image = SImageIO.read(new SFile(png.getAbsolutePath()));
 			if (sizeMode == SizeMode.ZOOM_FIT) {
 				final Dimension imageDim = new Dimension(image.getWidth(), image.getHeight());
 				final Dimension newImgDim = ImageHelper.getScaledDimension(imageDim,
@@ -335,7 +335,7 @@ class ImageWindow extends JFrame {
 			final TextBlockBackcolored error = GraphicStrings.createForError(Arrays.asList(msg), false);
 			try {
 				final byte[] bytes = plainPngBuilder(error).writeByteArray();
-				image = ImageIO.read(bytes);
+				image = SImageIO.read(bytes);
 			} catch (IOException e) {
 				e.printStackTrace();
 			}
@@ -389,7 +389,7 @@ class ImageWindow extends JFrame {
 		}
 		try {
 			final File png = generatedImage.getPngFile();
-			final Image image = ImageIO.read(png);
+			final Image image = SImageIO.read(png);
 			final ImageSelection imgSel = new ImageSelection(image);
 			Toolkit.getDefaultToolkit().getSystemClipboard().setContents(imgSel, null);
 		} catch (IOException e) {
