@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -39,16 +39,15 @@ import java.awt.Graphics2D;
 import java.awt.geom.AffineTransform;
 
 import net.sourceforge.plantuml.EnsureVisible;
-import net.sourceforge.plantuml.ugraphic.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.UDriver;
 import net.sourceforge.plantuml.ugraphic.UImage;
-import net.sourceforge.plantuml.ugraphic.UImageSvg;
 import net.sourceforge.plantuml.ugraphic.UParam;
-import net.sourceforge.plantuml.ugraphic.UShape;
+import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 
-public class DriverImageG2d implements UDriver<Graphics2D> {
+public class DriverImageG2d implements UDriver<UImage, Graphics2D> {
 
 	private final EnsureVisible visible;
+
 	private final double dpiFactor;
 
 	public DriverImageG2d(double dpiFactor, EnsureVisible visible) {
@@ -56,17 +55,17 @@ public class DriverImageG2d implements UDriver<Graphics2D> {
 		this.dpiFactor = dpiFactor;
 	}
 
-	public void draw(UShape ushape, double x, double y, ColorMapper mapper, UParam param, Graphics2D g2d) {
-		if (ushape instanceof UImageSvg) {
-			return;
-		}
-		final UImage shape = ((UImage) ushape);
+	public void draw(UImage shape, double x, double y, ColorMapper mapper, UParam param, Graphics2D g2d) {
 		visible.ensureVisible(x, y);
 		visible.ensureVisible(x + shape.getWidth(), y + shape.getHeight());
-		final AffineTransform back = g2d.getTransform();
-		g2d.scale(1 / dpiFactor, 1 / dpiFactor);
-		g2d.drawImage(shape.getImage(), (int) (x * dpiFactor), (int) (y * dpiFactor), null);
-		g2d.setTransform(back);
+		if (dpiFactor == 1) {
+			g2d.drawImage(shape.getImage(1), (int) (x), (int) (y), null);
+		} else {
+			final AffineTransform back = g2d.getTransform();
+			g2d.scale(1 / dpiFactor, 1 / dpiFactor);
+			g2d.drawImage(shape.getImage(dpiFactor), (int) (x * dpiFactor), (int) (y * dpiFactor), null);
+			g2d.setTransform(back);
+		}
 	}
 
 }
